@@ -48,6 +48,7 @@
 #include <QtGui/qpixmap.h>
 #include <QtGui/qimage.h>
 #include <QtGui/qtextoption.h>
+#include <memory>
 
 #ifndef QT_INCLUDE_COMPAT
 #include <QtGui/qpolygon.h>
@@ -90,7 +91,7 @@ public:
         VerticalSubpixelPositioning = 0x08,
         LosslessImageRendering = 0x40,
     };
-    Q_FLAG(RenderHint)
+    Q_ENUM(RenderHint)
 
     Q_DECLARE_FLAGS(RenderHints, RenderHint)
     Q_FLAG(RenderHints)
@@ -448,7 +449,7 @@ public:
 private:
     Q_DISABLE_COPY(QPainter)
 
-    QScopedPointer<QPainterPrivate> d_ptr;
+    std::unique_ptr<QPainterPrivate> d_ptr;
 
     friend class QWidget;
     friend class QFontEngine;
